@@ -24,12 +24,13 @@ class NavigationWindow : public CustomWindow {
 
  public slots:
   void setPosition(const QGeoPositionInfo &);
+  void setTarget(const QGeoCoordinate &);
 
  private:
   Cache m_cache;
   CoordinateTool *m_coordinateTool;
-  InfoWidget *m_latitude, *m_longitude;
-  QLabel *m_distance;
+  InfoWidget *m_latitude, *m_longitude, *m_distance;
+  QGeoCoordinate m_coo;
 };
 
 #endif
