@@ -6,12 +6,13 @@
 #include "cache.h"
 #include "iconloader.h"
 #include "htmlview.h"
+#include "waypointdb.h"
 
 class CacheWindow : public CustomWindow {
   Q_OBJECT;
 
  public:
-  CacheWindow(const Cache &, LocationProvider *, QWidget * = 0);
+  CacheWindow(const Cache &, LocationProvider *, WaypointDb *, QWidget * = 0);
   ~CacheWindow();
 
  private slots:
@@ -25,6 +26,7 @@ class CacheWindow : public CustomWindow {
   Cache m_cache;
   IconLoader m_iconLoader;
   LocationProvider *m_locationProvider;
+  WaypointDb *m_wptDb;
 };
 
 #endif
