@@ -1,10 +1,11 @@
 /* external string MACRO handling is broken under symbian^1 */
-#if 0 // def Q_OS_SYMBIAN
-#warning "Working around broken external symbian string macros!!"
+#ifdef S60V5
+#warning "Working around broken external symbian1 string macros!!"
 #define APPNAME "cacheme"
-#define VERSION "0.8.7"
+#define VERSION "0.8.8"
 #define DATADIR "/data/cacheme"
 #define LIBDIR "/data/cacheme"
+#define EXPIRATION_DATE "01102011"
 #endif
 
 class Config {
