@@ -1,3 +1,4 @@
+#include <QApplication>
 #include <QMainWindow>
 #include <QDebug>
 #include <QSettings>
@@ -37,7 +38,7 @@ void CustomWindow::reParent(CustomWindow *newParent) {
 CustomWindow::CustomWindow(const QString &name, QWidget *parent) : 
   QMainWindow(parent), m_name(name), m_iconLoader(NULL), 
   m_layout(NULL), m_title(NULL), m_parent(NULL)
-#ifdef Q_OS_SYMBIAN
+#ifdef SYMBIAN_BUTTON_INTERFACE
   ,iInterfaceSelector(NULL), iCoreTarget(NULL)
 #endif
 {
@@ -131,17 +132,29 @@ CustomWindow::CustomWindow(const QString &name, QWidget *parent) :
     layout->addWidget(button);    
     m_layout->addWidget(hbox);
 
+#if defined(Q_OS_SYMBIAN)
+    // get rid of "Action" menu entry in main screen
+    if(!m_parent)
+      vbox->setContextMenuPolicy(Qt::NoContextMenu);
+#endif
+
     QMainWindow::setCentralWidget(vbox);
   }
 #endif
-
 }
 
 void CustomWindow::setCentralWidget(QWidget *widget) {
   if(m_layout)
     m_layout->addWidget(widget);
-  else
+  else {
+#if defined(Q_OS_SYMBIAN)
+    // get rid of "Action" menu entry in main screen
+    if(!m_parent)
+      widget->setContextMenuPolicy(Qt::NoContextMenu);
+#endif
+
     QMainWindow::setCentralWidget(widget);    
+  }
 }
 
 void CustomWindow::setWindowTitle(const QString &title) {
@@ -183,6 +196,7 @@ CustomWindow::~CustomWindow() {
 
 #ifdef Q_OS_SYMBIAN
 void CustomWindow::show() {
+
   // symbian has problems displaying maximized windows which are
   // children of fullscreen windows. We thus force all child
   // windows to be fullscreen as well. But then we need to add
@@ -194,6 +208,9 @@ void CustomWindow::show() {
     qDebug() << __FUNCTION__ << "maximized";
     QWidget::showMaximized();
   }
+
+
+
 }
 #endif
 
@@ -222,7 +239,7 @@ void CustomWindow::keyPressEvent(QKeyEvent* event) {
 void CustomWindow::grabSpecialKeys(bool grab) {
   qDebug() << __FUNCTION__ << m_name << grab;
 
-#ifdef Q_OS_SYMBIAN
+#ifdef SYMBIAN_BUTTON_INTERFACE
   if(grab) {
     // under Symbian only one entity can grab the media keys. We let the map get them
     QT_TRAP_THROWING(iInterfaceSelector = CRemConInterfaceSelector::NewL());
@@ -237,7 +254,7 @@ void CustomWindow::grabSpecialKeys(bool grab) {
 #endif
 }
 
-#ifdef Q_OS_SYMBIAN
+#ifdef SYMBIAN_BUTTON_INTERFACE
 // Callback when media keys are pressed
 void CustomWindow::MrccatoCommand(TRemConCoreApiOperationId aOperationId,
 				  TRemConCoreApiButtonAction aButtonAct) {
