@@ -11,6 +11,7 @@
 #include "mapwidget.h"
 #include "cache.h"
 #include "cacheprovider.h"
+#include "waypointdb.h"
 
 class MainWindow : public CustomWindow {
   Q_OBJECT;
@@ -48,6 +49,8 @@ class MainWindow : public CustomWindow {
   LocationProvider *m_locationProvider;
   QString m_message;   
   QGraphicsView *m_view;
+
+  WaypointDb *m_wptDb;
 };
 
 #endif
