@@ -12,13 +12,14 @@ class MapButton : public QObject {
 
  public:
   enum State { Normal, Selected, Disabled };
-  MapButton(IconLoader *, const QString &, int, int, int, State);
+  MapButton(IconLoader *, const QString &, int, int, State);
   ~MapButton();
   void paint(const QSizeF &, QPainter *);
   QString name() const;
   bool setState(const State &);
   void change(IconLoader *, const QString &);
   void releaseImages();
+  void reload(IconLoader *);
 
   bool isInside(const QSizeF &, const QPointF &) const;
   bool mousePress(const QSizeF &, const QPointF &);
@@ -29,6 +30,7 @@ class MapButton : public QObject {
   void clicked();
 
  private:
+  QPoint screenPos(const QSizeF &) const;
   void renderNormal();
   void renderDisabled();
   void renderSelected();
@@ -41,6 +43,8 @@ class MapButton : public QObject {
   QString m_name;
 
   bool m_downOn;
+
+  static const int SHADOW_OFFSET = 8;
 };
 
 #endif // MAP_BUTTON_H
