@@ -194,9 +194,23 @@ void MapWidget::showBubble(const Cache &cache) {
   this->m_mapOverlay->enableForwardButton(cache.url().isValid());
 }
 
+void MapWidget::showBubble(const Waypoint &wpt) {
+  qDebug() << __FUNCTION__ << wpt.name();
+
+  hideBubble();
+  m_bubble = new MapBubble(this, size().width() > size().height(), wpt);
+  addMapObject(m_bubble);
+
+  this->m_mapOverlay->enableForwardButton(false);
+}
+
 // currently connected to the "forward" button
 void MapWidget::showDetails() {
   Q_ASSERT(m_bubble);
+
+  // the "showDetails" button is only enabled if 
+  // a cache is selected and not if a waypoint is selected
+
   emit detailClicked(m_bubble->cache().name());
 }
 
@@ -269,6 +283,7 @@ void MapWidget::mouseReleaseEvent(QGraphicsSceneMouseEvent* event) {
 	qDebug() << __FUNCTION__ << "User clicked waypoint" <<
 	  clickedWaypoint.name() << "of cache" << clickedCache;
 
+	showBubble(clickedWaypoint);
       }
     }
   }
@@ -342,7 +357,11 @@ void MapWidget::updateCaches(const CacheList &cacheList) {
 
   // save cache if existing bubble
   Cache bubbleCache;
-  if(m_bubble) bubbleCache = m_bubble->cache();
+  Waypoint bubbleWaypoint;
+  if(m_bubble) {
+    bubbleCache = m_bubble->cache();
+    bubbleWaypoint = m_bubble->wpt();
+  }
   hideBubble();
 
   // remove all existing caches
@@ -402,6 +421,9 @@ void MapWidget::updateCaches(const CacheList &cacheList) {
        viewport().contains(bubbleCache.coordinate()))
       showBubble(bubbleCache);
   }
+
+  if(bubbleWaypoint.coordinate().isValid())
+    showBubble(bubbleWaypoint);
 }
 
 void MapWidget::reloadTimerExpired() {
