@@ -1,8 +1,12 @@
 #ifndef NAVIGATIONWINDOW_H
 #define NAVIGATIONWINDOW_H
 
+#include <QSystemScreenSaver>
+
 #include "locationprovider.h"
 #include "customwindow.h"
+#include "coordinatetool.h"
+#include "waypointdb.h"
 #include "cache.h"
 
 class QLabel;
@@ -12,7 +16,8 @@ class NavigationWindow : public CustomWindow {
   Q_OBJECT;
 
  public:
-  NavigationWindow(const Cache &, LocationProvider *, QWidget * = 0);
+  NavigationWindow(const Cache &, LocationProvider *, 
+		   WaypointDb *, QWidget * = 0);
   ~NavigationWindow();
   QString distanceString(qreal distance);
   QString latitudeString(const QGeoCoordinate &);
@@ -21,11 +26,14 @@ class NavigationWindow : public CustomWindow {
 
  public slots:
   void setPosition(const QGeoPositionInfo &);
+  void setTarget(const QGeoCoordinate &);
 
  private:
   Cache m_cache;
-  InfoWidget *m_latitude, *m_longitude;
-  QLabel *m_distance;
+  CoordinateTool *m_coordinateTool;
+  InfoWidget *m_latitude, *m_longitude, *m_distance;
+  QGeoCoordinate m_coo;
+  QSystemScreenSaver m_screenSaver;
 };
 
 #endif
